package com.jclark.xsl;

import com.jclark.xml.parse.EntityManagerImpl;
import java.io.File;
import java.io.OutputStream;
import java.io.FileOutputStream;
import java.io.FileDescriptor;

public class Driver {
  public static void main(String[] args) {
    if (args.length != 2 && args.length != 3) {
      System.err.println("usage: jview com.jclark.xsl.Driver source stylesheet [result]");
      System.exit(1);
    }
    XMLProcessor parser = new XMLProcessorImpl();
    try {
      Sheet sheet
       = new EngineImpl().createSheet(EntityManagerImpl.fileToURL(new File(args[1])),
				      parser);
      OutputStream out = (args.length == 3
			  ? new FileOutputStream(args[2])
			  : new FileOutputStream(FileDescriptor.out));
      Result result;
      if (sheet.getIndentResult())
	result = new IndentResultImpl(out);
      else
	result = new ResultImpl(out);
      sheet.process(parser.load(EntityManagerImpl
				.fileToURL(new File(args[0]))),
		    result);
    }
    catch (java.io.IOException e) {
      System.err.println(e.getMessage());
    }
    catch (XSLException xe) {
      Node node = xe.getNode();
      if (node != null)
	System.err.print(node.getURL().toString() + ":"
			 + node.getLineNumber() + ":");
      try {
	throw xe.getException();
      }
      catch (XSLException e) {
	System.err.println(e.getMessage());
      }
      catch (com.jclark.xml.parse.NotWellFormedException e) {
	System.err.println(e.getMessage());
      }
      catch (java.io.IOException e) {
	System.err.println(e.getMessage());
      }
      catch (RuntimeException e) {
	throw e;
      }
      catch (Exception e) {
	throw new Error("unexpected exception " + e.getClass().toString());
      }
    }
  }
}
